==> haskell-tar-0.5.0.3-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.0.3
id: tar-0.5.0.3-Lj53UbIqLpELgGWYmsAfKo
key: tar-0.5.0.3-Lj53UbIqLpELgGWYmsAfKo
license: BSD3
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
exposed: True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Entry Codec.Archive.Tar.Check
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
abi: 51ce1f3ddcea622bd6adeef752f00af6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/tar-0.5.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/tar-0.5.0.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/tar-0.5.0.3
hs-libraries: HStar-0.5.0.3-Lj53UbIqLpELgGWYmsAfKo
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.2.6.2 filepath-1.4.1.0 time-1.6.0.1
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tar-0.5.0.3-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tar
version: 0.5.0.3
id: tar-0.5.0.3-60pC6grTbvG2zWoTgfDWBJ
key: tar-0.5.0.3-60pC6grTbvG2zWoTgfDWBJ
license: BSD3
copyright: 2007 Bjorn Bringert <bjorn@bringert.net>
           2008-2016 Duncan Coutts <duncan@community.haskell.org>
maintainer: Duncan Coutts <duncan@community.haskell.org>
synopsis: Reading, writing and manipulating ".tar" archive files.
description:
    This library is for working with \"@.tar@\" archive files. It
    can read and write a range of common variations of archive
    format including V7, POSIX USTAR and GNU formats.
    .
    It provides support for packing and unpacking portable
    archives. This makes it suitable for distribution but not
    backup because details like file ownership and exact
    permissions are not preserved.
    .
    It also provides features for random access to archive
    content using an index.
category: Codec
author: Duncan Coutts <duncan@community.haskell.org>
        Bjorn Bringert <bjorn@bringert.net>
exposed: True
exposed-modules:
    Codec.Archive.Tar Codec.Archive.Tar.Entry Codec.Archive.Tar.Check
    Codec.Archive.Tar.Index
hidden-modules: Codec.Archive.Tar.Types Codec.Archive.Tar.Read
                Codec.Archive.Tar.Write Codec.Archive.Tar.Pack
                Codec.Archive.Tar.Unpack Codec.Archive.Tar.Index.StringTable
                Codec.Archive.Tar.Index.IntTrie
abi: 4b7895749af101f5b051bc4a288e7232
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/tar-0.5.0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/tar-0.5.0.3
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/tar-0.5.0.3
hs-libraries: HStar-0.5.0.3-60pC6grTbvG2zWoTgfDWBJ
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0 filepath-1.4.1.1 time-1.6.0.1
haddock-interfaces: /usr/share/doc/haskell-tar/html/tar.haddock
haddock-html: /usr/share/doc/haskell-tar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
